==> openboard_1.5.4+dfsg1.orig.tar.xz: openboard-1.5.4/src/frameworks/UBStringUtils.h <==
/*
 * Copyright (C) 2015-2018 Département de l'Instruction Publique (DIP-SEM)
 *
 * Copyright (C) 2013 Open Education Foundation
 *
 * Copyright (C) 2010-2013 Groupement d'Intérêt Public pour
 * l'Education Numérique en Afrique (GIP ENA)
 *
 * This file is part of OpenBoard.
 *
 * OpenBoard is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License,
 * with a specific linking exception for the OpenSSL project's
 * "OpenSSL" library (or with modified versions of it that use the
 * same license as the "OpenSSL" library).
 *
 * OpenBoard is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenBoard. If not, see <http://www.gnu.org/licenses/>.
 */




#ifndef UBSTRINGUTILS_H
#define UBSTRINGUTILS_H

#include <QtCore>


class UBStringUtils
{

    private:
        UBStringUtils() {}
        ~UBStringUtils() {}

    public:
        static QStringList sortByLastDigit(const QStringList& source);

        static QString netxDigitizedName(const QString& source);

        static QString toCanonicalUuid(const QUuid& uuid);

        static QString toUtcIsoDateTime(const QDateTime& dateTime);
        static QDateTime fromUtcIsoDate(const QString& dateString);


};

#endif // UBSTRINGUTILS_H

==> openboard_1.6.4+dfsg.orig.tar.xz: openboard-1.6.4/src/frameworks/UBStringUtils.h <==
/*
 * Copyright (C) 2015-2022 Département de l'Instruction Publique (DIP-SEM)
 *
 * Copyright (C) 2013 Open Education Foundation
 *
 * Copyright (C) 2010-2013 Groupement d'Intérêt Public pour
 * l'Education Numérique en Afrique (GIP ENA)
 *
 * This file is part of OpenBoard.
 *
 * OpenBoard is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License,
 * with a specific linking exception for the OpenSSL project's
 * "OpenSSL" library (or with modified versions of it that use the
 * same license as the "OpenSSL" library).
 *
 * OpenBoard is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenBoard. If not, see <http://www.gnu.org/licenses/>.
 */




#ifndef UBSTRINGUTILS_H
#define UBSTRINGUTILS_H

#include <QtCore>


class UBStringUtils
{

    private:
        UBStringUtils() {}
        ~UBStringUtils() {}

    public:
        static bool containsPrefix(const QStringList& prefixes, const QString& string, Qt::CaseSensitivity cs);
        static QStringList sortByLastDigit(const QStringList& source);

        static QString nextDigitizedName(const QString& source);

        static QString toCanonicalUuid(const QUuid& uuid);

        static QString toUtcIsoDateTime(const QDateTime& dateTime);
        static QDateTime fromUtcIsoDate(const QString& dateString);


};

#endif // UBSTRINGUTILS_H
